@@ -333,37 +333,41 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, int type)
 		case SQL_SMALLINT:
 	
 			GB.NumberFromString(GB_NB_READ_INTEGER, data, strlen(data), &conv);
-			val->_integer.type = GB_T_INTEGER;
-			val->_integer.value = ((GB_INTEGER *) & conv)->value;
+			val->type = GB_T_INTEGER;
+			val->value._integer = ((GB_INTEGER *) & conv)->value;
 			if (strlen(data) == 0)
-				val->_integer.value = 0;
-
+				val->value._integer = 0;
 			break;
+			
 		case SQL_NUMERIC:
 		case SQL_FLOAT:
 		case SQL_REAL:
-			if (strlen(data) == 0) {
 			
-			val->_float.type = GB_T_FLOAT;
-			val->_float.value = 0;
-			}else 
+			if (strlen(data) == 0) 
 			{
-			GB.NumberFromString(GB_NB_READ_FLOAT, data, strlen(data), &conv);
-			val->_float.type = GB_T_FLOAT;
-			val->_float.value = ((GB_FLOAT *) & conv)->value;
+				val->type = GB_T_FLOAT;
+				val->value._float = 0;
+			}
+			else 
+			{
+				GB.NumberFromString(GB_NB_READ_FLOAT, data, strlen(data), &conv);
+				val->type = GB_T_FLOAT;
+				val->value._float = ((GB_FLOAT *) & conv)->value;
 			}
 			break;
+
 		case SQL_DOUBLE:
 			
-			if (strlen(data) == 0) {
-			
-			val->_float.type = GB_T_FLOAT;
-			val->_float.value = 0;
-			}else 
+			if (strlen(data) == 0) 
 			{
-			GB.NumberFromString(GB_NB_READ_FLOAT, data, strlen(data), &conv);
-			val->_float.type = GB_T_FLOAT;
-			val->_float.value = ((GB_FLOAT *) & conv)->value;
+				val->type = GB_T_FLOAT;
+				val->value._float = 0;
+			}
+			else 
+			{
+				GB.NumberFromString(GB_NB_READ_FLOAT, data, strlen(data), &conv);
+				val->type = GB_T_FLOAT;
+				val->value._float = ((GB_FLOAT *) & conv)->value;
 			}
 			break;
 
@@ -373,17 +377,17 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, int type)
 			GB.NumberFromString(GB_NB_READ_LONG, data, strlen(data), &conv);
 
 			val->type = GB_T_LONG;
-			val->_long.value = ((GB_LONG *) & conv)->value;
+			val->value._long = ((GB_LONG *) & conv)->value;
 
 			break;
 
 // Data type BLOB 
-   		case SQL_LONGVARCHAR:
+   	case SQL_LONGVARCHAR:
 		case SQL_VARBINARY:
 		case SQL_LONGVARBINARY:
     		// The BLOB are read by the blob_read() driver function
     		// You must set NULL there.
-				val->type = GB_T_NULL;
+			val->type = GB_T_NULL;
 			break;
 
 // Data type for Time
@@ -414,14 +418,12 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, int type)
 
 				GB.MakeDate(&date, (GB_DATE *) & conv);
 
-				val->_date.type = GB_T_DATE;
-				val->_date.date = ((GB_DATE *) & conv)->value.date;
-				val->_date.time = ((GB_DATE *) & conv)->value.time;
+				val->type = GB_T_DATE;
+				val->value._date.date = ((GB_DATE *) & conv)->value.date;
+				val->value._date.time = ((GB_DATE *) & conv)->value.time;
 				break;
 			}
 
-
-
 		case SQL_CHAR:
 		//case SQL_NUMERIC:
 		
@@ -430,8 +432,8 @@ static void conv_data(char *data, GB_VARIANT_VALUE * val, int type)
 
 			//val->_string.type = GB_T_STRING;
 			//GB.NewString(&val->_string.value, data, 0);
-			val->_string.type = GB_T_CSTRING;
-			val->_string.value = data;
+			val->type = GB_T_CSTRING;
+			val->value._string = data;
 
 			break;
 	}
@@ -930,7 +932,7 @@ fflush(stderr);
 	SQLULEN precision;
 	SQLSMALLINT scale;
 	SQLINTEGER i;
-	SQLINTEGER displaysize;
+	SQLLEN displaysize;
 	ODBC_FIELDS *field, *current;
 	SQLINTEGER collen;
 	int nresultcols;
@@ -1209,7 +1211,7 @@ if (displaysize>0)
 }
 
 	value.type = GB_T_VARIANT;
-	value.value._object.type = GB_T_NULL;
+	value.value.type = GB_T_NULL;
 	if(current==NULL)GB.Error("ODBC internal error 4");
 //fprintf(stderr,"Lunghezza letta = %d\n",read);
 	if (current)
@@ -1860,7 +1862,12 @@ fflush(stderr);
 	SQLLEN nIndicatorRemarks;
 	int compare = -1;
 	ODBC_CONN *han = (ODBC_CONN *)db->handle;
+	int len;
 
+	len = strlen(table);
+	if (len == 0)
+		return FALSE;
+	
 	retcode = SQLAllocHandle(SQL_HANDLE_STMT, han->odbcHandle, &statHandle);
 
 	if ((retcode != SQL_SUCCESS) && (retcode != SQL_SUCCESS_WITH_INFO))
@@ -1890,7 +1897,7 @@ fflush(stderr);
 	{
 
 		//printf("le tabelle in comparazione %s : %s\n",szTableName,table);
-		compare = strncmp((char *)szTableName, table, sizeof(table));
+		compare = strncmp((char *)szTableName, table, len);
 		szTableName[0] = '\0';
 		szTableType[0] = '\0';
 		szTableRemarks[0] = '\0';
@@ -2514,7 +2521,7 @@ fflush(stderr);
 	SQLHSTMT statHandle1;
 	SQLRETURN retcode;
 	//SQLRETURN V_OD_erg;
-	SQLINTEGER auton=SQL_FALSE;
+	SQLLEN auton=SQL_FALSE;
 	int i;
 	
 	ODBC_CONN *han = (ODBC_CONN *)db->handle;
@@ -2596,7 +2603,7 @@ fflush(stderr);
 		info->length = atol((char *) precision);
 if (auton==SQL_TRUE) info->type = DB_T_SERIAL;
 
-	info->def._object.type = GB_T_NULL;
+	info->def.type = GB_T_NULL;
 
 	SQLFreeHandle(SQL_HANDLE_STMT, statHandle);
 
