@@ -313,8 +313,8 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 	{
 		case BOOLOID:
 
-			val->_boolean.type = GB_T_BOOLEAN;
-			val->_boolean.value = conv_boolean(data);
+			val->type = GB_T_BOOLEAN;
+			val->value._boolean = conv_boolean(data);
 			break;
 
 		case INT2OID:
@@ -322,8 +322,8 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 
 			GB.NumberFromString(GB_NB_READ_INTEGER, data, strlen(data), &conv);
 
-			val->_integer.type = GB_T_INTEGER;
-			val->_integer.value = ((GB_INTEGER *)&conv)->value;
+			val->type = GB_T_INTEGER;
+			val->value._integer = ((GB_INTEGER *)&conv)->value;
 
 			break;
 
@@ -332,7 +332,7 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 			GB.NumberFromString(GB_NB_READ_LONG, data, strlen(data), &conv);
 
 			val->type = GB_T_LONG;
-			val->_long.value = ((GB_LONG *)&conv)->value;
+			val->value._long = ((GB_LONG *)&conv)->value;
 
 			break;
 
@@ -342,8 +342,8 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 
 			GB.NumberFromString(GB_NB_READ_FLOAT, data, strlen(data), &conv);
 
-			val->_float.type = GB_T_FLOAT;
-			val->_float.value = ((GB_FLOAT *)&conv)->value;
+			val->type = GB_T_FLOAT;
+			val->value._float = ((GB_FLOAT *)&conv)->value;
 
 			break;
 
@@ -401,9 +401,9 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 
 			GB.MakeDate(&date, (GB_DATE *)&conv);
 
-			val->_date.type = GB_T_DATE;
-			val->_date.date = ((GB_DATE *)&conv)->value.date;
-			val->_date.time = ((GB_DATE *)&conv)->value.time;
+			val->type = GB_T_DATE;
+			val->value._date.date = ((GB_DATE *)&conv)->value.date;
+			val->value._date.time = ((GB_DATE *)&conv)->value.time;
 
 			break;
 
@@ -421,8 +421,8 @@ static void conv_data(const char *data, int len, GB_VARIANT_VALUE *val, Oid type
 		case CASHOID:
 		default:
 
-			val->_string.type = GB_T_CSTRING;
-			val->_string.value = (char *)data;
+			val->type = GB_T_CSTRING;
+			val->value._string = (char *)data;
 			//val->_string.len = len;
 
 			break;
@@ -814,7 +814,7 @@ static int query_fill(DB_DATABASE *db, DB_RESULT result, int pos, GB_VARIANT_VAL
 		data = PQgetvalue(res, pos, i);
 
 		value.type = GB_T_VARIANT;
-		value.value._object.type = GB_T_NULL;
+		value.value.type = GB_T_NULL;
 
 		if (!PQgetisnull(res, pos, i))
 			conv_data(data, PQgetlength(res, pos, i), &value.value, PQftype(res, i));
@@ -897,10 +897,9 @@ static char *field_name(DB_RESULT result, int field)
 static int field_index(DB_RESULT Result, const char *name, DB_DATABASE *db)
 {
 	PGresult *result = (PGresult *)Result;
-
 	char *fld;
 	int index;
-	char *table;
+	char *table = NULL;
 	int numfields, oid;
 	char *qfield =
 		"select oid from pg_class where relname = '&1' "
@@ -1106,7 +1105,7 @@ static int table_init(DB_DATABASE *db, const char *table, DB_INFO *info)
 			"from pg_class, pg_attribute "
 			"where pg_class.relname = '&1' "
 				"and (pg_class.relnamespace not in (select oid from pg_namespace where nspname = 'information_schema')) "
-				"and pg_attribute.attnum > 0 "
+				"and pg_attribute.attnum > 0 and not pg_attribute.attisdropped "
 				"and pg_attribute.attrelid = pg_class.oid ";
 
 	PGresult *res;
@@ -1687,7 +1686,7 @@ static int field_exist(DB_DATABASE *db, const char *table, const char *field)
 		"where pg_class.relname = '&1' "
 		"and (pg_class.relnamespace not in (select oid from pg_namespace where nspname = 'information_schema')) "
 		"and pg_attribute.attname = '&2' "
-		"and pg_attribute.attnum > 0 "
+		"and pg_attribute.attnum > 0 and not pg_attribute.attisdropped "
 		"and pg_attribute.attrelid = pg_class.oid ";
 
 	PGresult *res;
@@ -1726,7 +1725,7 @@ static int field_list(DB_DATABASE *db, const char *table, char ***fields)
 	const char *query = "select pg_attribute.attname from pg_class, pg_attribute "
 		"where pg_class.relname = '&1' "
 		"and (pg_class.relnamespace not in (select oid from pg_namespace where nspname = 'information_schema')) "
-		"and pg_attribute.attnum > 0 "
+		"and pg_attribute.attnum > 0 and not pg_attribute.attisdropped "
 		"and pg_attribute.attrelid = pg_class.oid";
 
 	PGresult *res;
@@ -1777,7 +1776,7 @@ static int field_info(DB_DATABASE *db, const char *table, const char *field, DB_
 		"where pg_class.relname = '&1' "
 		"and (pg_class.relnamespace not in (select oid from pg_namespace where nspname = 'information_schema')) "
 		"and pg_attribute.attname = '&2' "
-		"and pg_attribute.attnum > 0 "
+		"and pg_attribute.attnum > 0 and not pg_attribute.attisdropped "
 		"and pg_attribute.attrelid = pg_class.oid";
 
 	PGresult *res;
@@ -1809,12 +1808,12 @@ static int field_info(DB_DATABASE *db, const char *table, const char *field, DB_
 			info->length -= 4;
 	}
 
-	info->def._object.type = GB_T_NULL;
+	info->def.type = GB_T_NULL;
 
 	if (conv_boolean(PQgetvalue(res, 0, 3)))
 	{
 		def.type = GB_T_VARIANT;
-		def.value._object.type = GB_T_NULL;
+		def.value.type = GB_T_NULL;
 
 		val = PQgetvalue(res, 0, 4);
 		if (val && *val)
@@ -1829,8 +1828,8 @@ static int field_info(DB_DATABASE *db, const char *table, const char *field, DB_
 				switch(info->type)
 				{
 					case GB_T_BOOLEAN:
-						def.value._boolean.value = (val[1] == 't');
-						def.value._boolean.type = GB_T_BOOLEAN;
+						def.value.type = GB_T_BOOLEAN;
+						def.value.value._boolean = (val[1] == 't');
 						break;
 
 					default:
