@@ -29,9 +29,7 @@
 #ifndef __CSTOCK_H
 #define __CSTOCK_H
 
-#include "gambas.h"
-#include "widgets.h"
-
+#include "main.h"
 
 #ifndef __CSTOCK_CPP
 
@@ -39,9 +37,4 @@ extern GB_DESC CStockDesc[];
 
 #endif
 
-
-
-
-
-
 #endif
