@@ -26,7 +26,6 @@
 
 ***************************************************************************/
 
-
 #define __CTEXTBOX_CPP
 
 #include <stdlib.h>
@@ -61,12 +60,6 @@ static void txt_raise_activate(gTextBox *sender)
 	GB.Raise(THIS, EVENT_Activate, 0);
 }
 
-static void cmb_raise_click(gComboBox *sender)
-{
-	CWIDGET *_object = GetObject((gControl*)sender);
-	GB.Raise(THIS, EVENT_Click, 0);
-}
-
 /***************************************************************************
 
   TextBox
@@ -241,6 +234,16 @@ END_METHOD
 #undef THIS
 #define THIS ((CCOMBOBOX *)_object)
 
+static void cmb_raise_click(gComboBox *sender)
+{
+	CWIDGET *_object = GetObject((gControl*)sender);
+	if (THIS->click)
+		return;
+	THIS->click = TRUE;
+	GB.Raise(THIS, EVENT_Click, 0);
+	THIS->click = FALSE;
+}
+
 
 BEGIN_METHOD(CCOMBOBOX_new, GB_OBJECT parent)
 
@@ -374,6 +377,7 @@ BEGIN_PROPERTY(CCOMBOBOX_list)
 	}
 	else
 	{
+		GB.NewString(&text, COMBOBOX->text(), 0);
 		array = VPROP(GB_OBJECT);
 		COMBOBOX->lock();
 		COMBOBOX->clear();
@@ -382,10 +386,10 @@ BEGIN_PROPERTY(CCOMBOBOX_list)
 			for (i = 0; i < GB.Array.Count(array); i++)
 				COMBOBOX->add(*((char **)GB.Array.Get(array, i)));
 		}
-		COMBOBOX->setIndex(-1);
+
+		COMBOBOX->setText(text);
 		COMBOBOX->unlock();
-		if (array)
-			COMBOBOX->setIndex(0);
+		GB.FreeString(&text);
 	}
 
 END_PROPERTY
