@@ -111,6 +111,9 @@ int gKey::fromString(char *str)
 	char *lstr;
 	int key;
 	
+	if (!str || !*str)
+		return 0;
+	
 	lstr = g_ascii_strup(str, -1);
 	key = gdk_keyval_from_name(lstr);
 	g_free(lstr);
@@ -309,20 +312,14 @@ static void gambas_handle_event(GdkEvent *event)
 		real = false;
 	}
 	
+	/*if (event->type == GDK_BUTTON_PRESS)
+		fprintf(stderr, "GDK_BUTTON_PRESS: %p %s\n", widget, control ? control->name() : NULL);
+	else if (event->type == GDK_KEY_PRESS)
+		fprintf(stderr, "GDK_KEY_PRESS: %p %s\n", widget, control ? control->name() : NULL);*/
+	
 	if (!widget || !control)
 		goto __HANDLE_EVENT;
 	
-	/*switch ((int)event->type)
-	{
-		case GDK_ENTER_NOTIFY:
-			fprintf(stderr, "ENTER: %p %s\n", control, control ? control->name() : 0);
-			break;
-		
-		case GDK_LEAVE_NOTIFY:
-			fprintf(stderr, "LEAVE: %p %s\n", control, control ? control->name() : 0);
-			break;
-	}*/
-	
 	grab = gtk_grab_get_current();
 	
 	if (grab && !is_child_of(widget, grab))
@@ -737,6 +734,7 @@ void gApplication::setBusy(bool b)
     iter = g_list_next(iter);
   }
   
+  do_iteration(true, true);
 }
 
 static bool _dirty = false;
