@@ -40,6 +40,7 @@ public:
 	int mouse();
 	gControl *next();
 	gControl *previous();
+	void getScreenPos(int *x, int *y);
 	int screenX();
 	int screenY();
 	char *toolTip();
@@ -128,10 +129,10 @@ public:
 
 // "Signals"
 	void (*onFinish)(gControl *sender); // Special
-	void (*onFocusEvent)(gControl *sender,long type);
-	bool (*onKeyEvent)(gControl *sender,long type);
-	bool (*onMouseEvent)(gControl *sender,long type);
-	void (*onEnterLeave)(gControl *sender,long type);
+	void (*onFocusEvent)(gControl *sender, int type);
+	bool (*onKeyEvent)(gControl *sender, int type);
+	bool (*onMouseEvent)(gControl *sender, int type);
+	void (*onEnterLeave)(gControl *sender, int type);
 	bool (*onDrag)(gControl *sender);
 	bool (*onDragMove)(gControl *sender);
 	void (*onDrop)(gControl *sender);
@@ -145,6 +146,7 @@ public:
 	GtkWidget *widget;
 	GtkWidget *border;
 	GtkWidget *frame;
+	GtkScrolledWindow *_scroll;
 	short g_typ;
 	short mous;
 	
@@ -183,6 +185,8 @@ public:
 	void setParent(gContainer *parent) { pr = parent; }
 	void initAll(gContainer *pr);
 	void realize(bool make_frame = false);
+	void realizeScrolledWindow(GtkWidget *wid, bool doNotRealize = false);
+	void registerControl();
 	void updateGeometry();
 	bool mustUpdateCursor() { return mouse() != -1 || have_cursor; }
 	
@@ -191,6 +195,8 @@ public:
 	virtual void updateBorder();
 	int getFrameBorder() { return frame_border; }
 	void setFrameBorder(int border);
+	void setBorder(bool b);
+	bool hasBorder();
 	int getFramePadding() { return frame_padding; }
 	void setFramePadding(int padding);
 	virtual int getFrameWidth();
@@ -198,6 +204,8 @@ public:
 	
 	virtual int minimumHeight();
 	
+	void resolveFont(gFont *new_font);
+	
 /*	static gControl* dragWidget();
 	static void setDragWidget(gControl *ct);
 	static char *dragTextBuffer();
