@@ -37,19 +37,6 @@ static gboolean cb_expose(GtkWidget *draw, GdkEventExpose *e, gLabel *d)
 	GdkGC *gc;
 	int vw,vh,lw,lh;
 	int fw = d->getFrameWidth();
-/*	int width;
-	
-	if (d->markup)
-	{
-		width = d->width() - fw * 2;
-		if (width < 0)
-			return false;
-		width *= PANGO_SCALE;
-	}
-	else
-		width = -1;
-		
-	pango_layout_set_width(d->layout, width);*/
 	
 	gc = gdk_gc_new(draw->window);
 	
@@ -176,12 +163,13 @@ void gLabel::updateLayout()
 	gt_add_layout_from_font(layout, font());
 }
 
+
 void gLabel::updateSize(bool adjust, bool noresize)
 {
 	gint w, h;
 	int fw;
 	
-	if (_locked)
+	if (_locked || !textdata || !*textdata)
 		return;
 	
 	fw = getFrameWidth();
@@ -202,9 +190,15 @@ void gLabel::updateSize(bool adjust, bool noresize)
 		return;
 		
 	pango_layout_get_pixel_size(layout, &w, &h);
-	//fprintf(stderr, "gLabel::updateSize: %s (%d %d) -> (%d %d)\n", name(), width(), height(), w + fw * 2, h + fw * 2);
+	
+	w += fw * 2;
+	h += fw * 2;
+	
+	if ((align == ALIGN_CENTER || align == ALIGN_LEFT || align == ALIGN_NORMAL || align == ALIGN_RIGHT) && h < height())
+		h = height();
+	
 	_locked = true;
-	resize(width(), h + fw * 2);	
+	resize(w, h);	
 	_locked = false;
 }
 
@@ -251,6 +245,8 @@ char *gLabel::text()
 
 void gLabel::setText(char *vl)
 {
+	bool no_text_before = !textdata || !*textdata;
+	
 	g_free(textdata);
 	
 	if (vl)
@@ -260,6 +256,10 @@ void gLabel::setText(char *vl)
 
 	updateLayout();
 	updateSize();
+	
+	if (no_text_before && _transparent)
+		gtk_widget_shape_combine_mask(border, NULL, 0, 0);
+	
 	refresh();
 }
 
