@@ -30,7 +30,7 @@
 #include "widgets_private.h"
 #include "gspinbox.h"
 
-void  spin_change(GtkSpinButton *spinbutton,gSpinBox *data)
+static void cb_change(GtkSpinButton *spinbutton,gSpinBox *data)
 {
 	data->selectAll();
 	if (data->onChange) data->onChange(data);
@@ -52,45 +52,46 @@ gSpinBox::gSpinBox(gContainer *parent) : gControl(parent)
 	
 	onChange = NULL;
 	
-	g_signal_connect(G_OBJECT(widget),"value-changed",G_CALLBACK(spin_change),(gpointer)this);
+	g_signal_connect(G_OBJECT(widget),"value-changed",G_CALLBACK(cb_change),(gpointer)this);
 }
 
 
-long gSpinBox::background()
+/*int gSpinBox::background()
 {
 	return get_gdk_base_color(widget);
 }
 
-void gSpinBox::setBackground(long color)
+void gSpinBox::setBackground(int color)
 {
 	set_gdk_base_color(widget,color);	
 	if (!border->window) gtk_widget_realize(border);
 	gdk_window_process_updates(border->window,true);
 }
 
-long gSpinBox::foreground()
+int gSpinBox::foreground()
 {
 	return get_gdk_text_color(widget);
 }
 
-void gSpinBox::setForeground(long color)
+void gSpinBox::setForeground(int color)
 {	
 	set_gdk_text_color(widget,color);
 	if (!border->window) gtk_widget_realize(border);
 	gdk_window_process_updates(border->window,true);
-}
+}*/
 
-long gSpinBox::step()
+int gSpinBox::step()
 {
 	gdouble step;
 	
 	gtk_spin_button_get_increments(GTK_SPIN_BUTTON(widget),&step,NULL);
-	return (long)step;
+	return (int)step;
 }
 
-long gSpinBox::value()
+int gSpinBox::value()
 {
-	return (long)gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget));
+	gtk_spin_button_update(GTK_SPIN_BUTTON(widget));
+	return (int)gtk_spin_button_get_value(GTK_SPIN_BUTTON(widget));
 }
 
 bool gSpinBox::wrap()
@@ -98,25 +99,25 @@ bool gSpinBox::wrap()
 	return gtk_spin_button_get_wrap(GTK_SPIN_BUTTON(widget));
 }
 	
-void gSpinBox::setMaxValue(long vl)
+void gSpinBox::setMaxValue(int vl)
 {
 	_max = vl;
 	gtk_spin_button_set_range(GTK_SPIN_BUTTON(widget),_min, _max);
 }
 
-void gSpinBox::setMinValue(long vl)
+void gSpinBox::setMinValue(int vl)
 {
 	_min = vl;
 	gtk_spin_button_set_range(GTK_SPIN_BUTTON(widget), _min, _max);
 }
 
-void gSpinBox::setStep(long vl)
+void gSpinBox::setStep(int vl)
 {
 	gdouble step = (gdouble)vl;
 	gtk_spin_button_set_increments(GTK_SPIN_BUTTON(widget), step, step);
 }
 
-void gSpinBox::setValue(long vl)
+void gSpinBox::setValue(int vl)
 {
 	if (vl == value())
 		return;
