@@ -105,6 +105,7 @@ public:
 	int count();
 	gControl *child(int n);
 	void updateColors();
+	void updateFont();
 
 	GtkWidget *fix;
 	GtkWidget *widget;
@@ -120,6 +121,8 @@ public:
 
 gTabStripPage::gTabStripPage(gTabStrip *tab)
 {
+	char text[16];
+	
 	parent = tab;
 	
 	widget = gtk_layout_new(0,0);
@@ -141,6 +144,7 @@ gTabStripPage::gTabStripPage(gTabStrip *tab)
 	//gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
 	
 	updateColors();
+	updateFont();
 	
 	g_signal_connect(G_OBJECT(widget),"button-press-event",G_CALLBACK(gTabStrip_buttonPress),(gpointer)parent);
 	g_signal_connect(G_OBJECT(widget),"button-release-event",G_CALLBACK(gTabStrip_buttonRelease),(gpointer)parent);
@@ -161,6 +165,8 @@ gTabStripPage::gTabStripPage(gTabStrip *tab)
 	
 	gtk_widget_hide(image);
 	
+	sprintf(text, "Tab %d", index);
+	setText(text);
 	setVisible(true);
 }
 
@@ -174,9 +180,16 @@ gTabStripPage::~gTabStripPage()
 
 void gTabStripPage::updateColors()
 {
-	set_gdk_bg_color(widget, parent->background());
+	set_gdk_bg_color(widget, parent->realBackground());
 	//set_gdk_bg_color(fix, parent->background());
-	set_gdk_fg_color(label, parent->foreground());
+	set_gdk_fg_color(label, parent->realForeground());
+}
+
+void gTabStripPage::updateFont()
+{
+	gFont *fnt = parent->font();
+	gtk_widget_modify_font(widget, fnt ? fnt->desc() : NULL);
+	gtk_widget_modify_font(label, fnt ? fnt->desc() : NULL);
 }
 
 void gTabStripPage::setText(char *text)
@@ -247,7 +260,7 @@ void gTabStripPage::setVisible(bool v)
 			if (page->isVisible())
 				n++;
 		}
-		gtk_notebook_insert_page(GTK_NOTEBOOK(parent->border), widget, fix, n);
+		gtk_notebook_insert_page(GTK_NOTEBOOK(parent->widget), widget, fix, n);
 		gtk_widget_realize(widget);
 		gtk_widget_realize(fix);
 		gtk_widget_show_all(widget);
@@ -257,8 +270,8 @@ void gTabStripPage::setVisible(bool v)
 	}
 	else
 	{
-		ind = gtk_notebook_page_num(GTK_NOTEBOOK(parent->border), widget);
-		gtk_notebook_remove_page(GTK_NOTEBOOK(parent->border), ind);
+		ind = gtk_notebook_page_num(GTK_NOTEBOOK(parent->widget), widget);
+		gtk_notebook_remove_page(GTK_NOTEBOOK(parent->widget), ind);
 	}
 }
 
@@ -320,6 +333,7 @@ gTabStrip::gTabStrip(gContainer *parent) : gContainer(parent)
 	_pages = g_ptr_array_new();
 	onClick=NULL;
 	
+	border = gtk_event_box_new();
 	widget = gtk_notebook_new();
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(widget), TRUE);
 	gtk_drag_dest_unset(widget);
@@ -340,7 +354,7 @@ gTabStrip::gTabStrip(gContainer *parent) : gContainer(parent)
   */
   
 	gtk_widget_add_events(widget,GDK_BUTTON_RELEASE_MASK);
-	g_signal_connect_after(G_OBJECT(border), "switch-page", G_CALLBACK(cb_click), (gpointer)this);
+	g_signal_connect_after(G_OBJECT(widget), "switch-page", G_CALLBACK(cb_click), (gpointer)this);
 }
 
 gTabStrip::~gTabStrip()
@@ -369,7 +383,7 @@ int gTabStrip::getRealIndex(GtkWidget *page)
 
 int gTabStrip::index()
 {
-	GtkWidget *page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(border), gtk_notebook_get_current_page(GTK_NOTEBOOK(border)));
+	GtkWidget *page = gtk_notebook_get_nth_page(GTK_NOTEBOOK(widget), gtk_notebook_get_current_page(GTK_NOTEBOOK(widget)));
 	return getRealIndex(page);
 }
 
@@ -380,13 +394,13 @@ void gTabStrip::setIndex(int vl)
 	if ( (vl<0) || (vl>=count()) || !get(vl)->isVisible() ) return;
 	
 	page = get(vl)->widget;
-	gtk_notebook_set_current_page(GTK_NOTEBOOK(border), getRealIndex(page));
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(widget), getRealIndex(page));
 	//widget = get(vl)->widget;
 }
 
 int gTabStrip::orientation()
 {
-	switch ( gtk_notebook_get_tab_pos(GTK_NOTEBOOK(border)) )
+	switch ( gtk_notebook_get_tab_pos(GTK_NOTEBOOK(widget)) )
 	{
 		case GTK_POS_TOP: return 0;
 		default: return 1;
@@ -417,10 +431,14 @@ bool gTabStrip::setCount(int vl)
 
 	ind = index();
 
-	lock();
-	while (vl > count())
-		g_ptr_array_add(_pages, (gpointer)new gTabStripPage(this));
-	unlock();
+	if (vl > count())
+	{
+		lock();
+		while (vl > count())
+			g_ptr_array_add(_pages, (gpointer)new gTabStripPage(this));
+		setIndex(count() - 1);
+		unlock();
+	}
 	
 	if (vl < count())
 	{
@@ -462,9 +480,9 @@ void gTabStrip::setOrientation(int vl)
 	switch (vl)
 	{
 		case 0:
-			gtk_notebook_set_tab_pos(GTK_NOTEBOOK(border),GTK_POS_TOP); break;
+			gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget),GTK_POS_TOP); break;
 		case 1:
-			gtk_notebook_set_tab_pos(GTK_NOTEBOOK(border),GTK_POS_BOTTOM); break;
+			gtk_notebook_set_tab_pos(GTK_NOTEBOOK(widget),GTK_POS_BOTTOM); break;
 	}
 }
 
@@ -583,3 +601,13 @@ gTabStripPage *gTabStrip::get(int ind)
 	else 
 		return (gTabStripPage *)g_ptr_array_index(_pages, ind);
 }
+
+void gTabStrip::setFont(gFont *font)
+{
+	int i;
+	
+	gControl::setFont(font);
+	
+	for (i = 0; i < count(); i++)
+		get(i)->updateFont();	
+}
