@@ -33,7 +33,7 @@ void gt_shortcut_parse(char *shortcut, guint *key, GdkModifierType *mods);
 
 // Converts HTML to Pango format
 
-char* gt_html_to_pango_string(char *html, int len_html, bool newline);
+char* gt_html_to_pango_string(const char *html, int len_html, bool newline);
 
 // Converts to/from GTK+ alignment
 
@@ -46,10 +46,6 @@ GtkStyle *gt_get_style(const char *name, int type);
 
 // Global signal handlers
 
-gboolean gcb_keypress (GtkWidget *widget, GdkEventKey *event, gControl *data);
-gboolean gcb_keyrelease (GtkWidget *widget, GdkEventKey *event, gControl *data);
-gboolean gcb_button_press(GtkWidget *widget,GdkEventButton *event,gControl *data);
-gboolean gcb_button_release(GtkWidget *widget,GdkEventButton *event,gControl *data);
 gboolean gcb_focus_in(GtkWidget *widget,GdkEventFocus *event,gControl *data);
 gboolean gcb_focus_out(GtkWidget *widget,GdkEventFocus *event,gControl *data);
 
@@ -111,3 +107,5 @@ void gt_set_layout_from_font(PangoLayout *layout, gFont *font);
 void gt_add_layout_from_font(PangoLayout *layout, gFont *font);
 
 #define gt_pango_to_pixel(_pango) (((_pango) + PANGO_SCALE - 1) / PANGO_SCALE)
+
+#define gt_object_unref_sink(_object) (g_object_ref_sink(G_OBJECT(_object)), g_object_unref(G_OBJECT(_object)))
