@@ -103,22 +103,27 @@ void CUdpSocket_CallBack(int t_sock,int type,long param)
 /* not allowed methods */
 int CUdpSocket_stream_open(GB_STREAM *stream, const char *path, int mode, void *data){return -1;}
 int CUdpSocket_stream_seek(GB_STREAM *stream, int64_t pos, int whence){return -1;}
+
 int CUdpSocket_stream_tell(GB_STREAM *stream, int64_t *pos)
 {
 	*pos=0;
 	return -1; /* not allowed */
 }
+
 int CUdpSocket_stream_flush(GB_STREAM *stream)
 {
 	return 0; /* OK */
 }
+
 int CUdpSocket_stream_handle(GB_STREAM *stream)
 {
-	return 0; /* OK */
+	void *_object = stream->tag;
+	return THIS->Socket;
 }
+
 int CUdpSocket_stream_close(GB_STREAM *stream)
 {
-	void *_object=((void**)stream->_free)[0];
+	void *_object = stream->tag;
 
 	if ( !_object ) return -1;
 	stream->desc=NULL;
@@ -137,9 +142,10 @@ int CUdpSocket_stream_close(GB_STREAM *stream)
 	THIS->iStatus=0;
 	return 0;
 }
+
 int CUdpSocket_stream_lof(GB_STREAM *stream, int64_t *len)
 {
-	void *_object=((void**)stream->_free)[0];
+	void *_object = stream->tag;
 	int bytes;
 
 	if ( !_object ) return -1;
@@ -152,9 +158,10 @@ int CUdpSocket_stream_lof(GB_STREAM *stream, int64_t *len)
 	*len=bytes;
 	return 0;
 }
+
 int CUdpSocket_stream_eof(GB_STREAM *stream)
 {
-	void *_object=((void**)stream->_free)[0];
+	void *_object = stream->tag;
 	int bytes;
 
 	if ( !_object ) return -1;
@@ -171,8 +178,8 @@ int CUdpSocket_stream_eof(GB_STREAM *stream)
 
 int CUdpSocket_stream_read(GB_STREAM *stream, char *buffer, int len)
 {
-	void *_object=((void**)stream->_free)[0];
-    	int retval;
+	void *_object = stream->tag;
+	int retval;
 	int bytes=0;
 	int NoBlock=0;
 	unsigned int rem_host_len;
@@ -207,8 +214,8 @@ int CUdpSocket_stream_read(GB_STREAM *stream, char *buffer, int len)
 
 int CUdpSocket_stream_write(GB_STREAM *stream, char *buffer, int len)
 {
-	void *_object=((void**)stream->_free)[0];
-    	int retval;
+	void *_object = stream->tag;
+	int retval;
 	int NoBlock=0;
 	struct sockaddr_in remhost;
 	struct in_addr rem_ip;
@@ -223,6 +230,9 @@ int CUdpSocket_stream_write(GB_STREAM *stream, char *buffer, int len)
 	remhost.sin_addr.s_addr=rem_ip.s_addr;
 	bzero(&(remhost.sin_zero),8);
 	ioctl(THIS->Socket,FIONBIO,&NoBlock);
+
+	//fprintf(stderr, "write: %s %d %d '%.*s'\n", THIS->thost, THIS->tport, len, len, buffer);
+	
 	USE_MSG_NOSIGNAL(retval=sendto(THIS->Socket,(void*)buffer,len*sizeof(char) \
 		              ,MSG_NOSIGNAL,(struct sockaddr*)&remhost,sizeof(struct sockaddr)));
 	NoBlock++;
@@ -293,7 +303,7 @@ static int dgram_start(CUDPSOCKET *mythis,int myport)
 
 	mythis->iStatus=1;
 	ioctl(mythis->Socket,FIONBIO,&NoBlock);
-	GB.Watch (mythis->Socket,GB_WATCH_WRITE,(void *)CUdpSocket_CallBack,(long)mythis);
+	GB.Watch (mythis->Socket,GB_WATCH_READ,(void *)CUdpSocket_CallBack,(long)mythis);
 	mythis->stream.desc=&UdpSocketStream;
 	return 0;
 }
@@ -344,7 +354,7 @@ BEGIN_PROPERTY ( CUDPSOCKET_TargetPort )
 
   if (READ_PROPERTY)
   {
-  	GB.ReturnInteger(THIS->sport);
+  	GB.ReturnInteger(THIS->tport);
 	return;
   }
 
@@ -362,7 +372,7 @@ END_PROPERTY
  *************************************************/
 BEGIN_METHOD(CUDPSOCKET_new,GB_INTEGER Port;)
 
-	((void**)THIS->stream._free)[0]=_object;
+	THIS->stream.tag = _object;
 	if (MISSING (Port) ) return;
 	dgram_start(THIS,VARG(Port));
 
@@ -444,7 +454,7 @@ BEGIN_METHOD (CUDPSOCKET_Bind,GB_INTEGER Port;)
 			GB.Error("Already working");
 			return;
 		case 8:
-			GB.Error("Port value is not valid.");
+			GB.Error("Port value is not valid");
 			return;
 	}
 
