@@ -34,7 +34,11 @@ DECLARE_METHOD(GLEDGEFLAG);
 DECLARE_METHOD(GLEND);
 DECLARE_METHOD(GLRECTF);
 DECLARE_METHOD(GLRECTI);
+DECLARE_METHOD(GLVERTEX2F);
+DECLARE_METHOD(GLVERTEX3F);
 DECLARE_METHOD(GLVERTEXF);
+DECLARE_METHOD(GLVERTEX2I);
+DECLARE_METHOD(GLVERTEX3I);
 DECLARE_METHOD(GLVERTEXI);
 DECLARE_METHOD(GLVERTEXFV);
 DECLARE_METHOD(GLVERTEXIV);
