@@ -41,7 +41,7 @@
 #define CTEXTAREA_PROPERTIES "*,Text,ReadOnly,Wrap,Border=True,ScrollBar{Scroll.*}=Both"
 #define CTEXTEDIT_PROPERTIES "*,ReadOnly,ScrollBar{Scroll.*}=Both,Border=True"
 #define CLISTBOX_PROPERTIES "*,List,Mode{Select.*}=Single,Sorted"
-#define CCOMBOBOX_PROPERTIES "*,Text,ReadOnly,Password,MaxLength,List,Sorted"
+#define CCOMBOBOX_PROPERTIES "*,ReadOnly,List,Text,Password,MaxLength,Sorted"
 #define CBUTTON_PROPERTIES "*,Action,Text,Picture,Border=True,Default,Cancel"
 #define CTOGGLEBUTTON_PROPERTIES "*,Action,Text,Picture,Border=True,Radio,Value"
 #define CTOOLBUTTON_PROPERTIES "*,Action,Text,Picture,Border,Radio,Toggle,Value"
