@@ -852,7 +852,8 @@ END_PROPERTY
 
 BEGIN_PROPERTY(CTREEVIEW_count)
 
-  GB.ReturnInteger(WIDGET->childCount());
+  //GB.ReturnInteger(WIDGET->childCount());
+	GB.ReturnInteger(THIS->dict->count());
 
 END_PROPERTY
 
