@@ -30,6 +30,8 @@
 
 #include "CEditor.h"
 
+#define MAX_CONSOLE_WIDTH 256
+
 DECLARE_EVENT(EVENT_Change);
 DECLARE_EVENT(EVENT_Cursor);
 DECLARE_EVENT(EVENT_Scroll);
@@ -185,9 +187,11 @@ BEGIN_METHOD(CEDITORDOC_insert, GB_STRING str; GB_INTEGER y; GB_INTEGER x)
 
 END_METHOD
 
-static void print_text(void *_object, const QString &s)
+static void print_text(void *_object, const char *str, int lstr, bool esc = false)
 {
+	QString s = QString::fromUtf8(str, lstr);
   int line, col;
+  uint i, len;
 	
 	WIDGET->getCursor(&line, &col);
 	if (col == 0)
@@ -203,59 +207,95 @@ static void print_text(void *_object, const QString &s)
 // 			end = DOC->lineLength(line);
 // 		DOC->remove(line, col, line, end);
 // 	}
-	WIDGET->insert(s);
+	
+	if (!esc)
+	{
+		i = 0;
+		for (;;)
+		{
+			if (col == MAX_CONSOLE_WIDTH)
+			{
+				WIDGET->insert("\n");
+				col = 0;
+			}
+			len = s.length() - i;
+			if ((col + len) >= MAX_CONSOLE_WIDTH)
+				len = MAX_CONSOLE_WIDTH - col;
+			WIDGET->insert(s.mid(i, len));
+			i += len;	
+			if (i >= s.length())
+				break;
+			col += len;
+		}
+	}
+	else
+	{
+		if (col >= MAX_CONSOLE_WIDTH)
+			WIDGET->insert("\n");
+		WIDGET->insert(s);
+	}
 }
 
 BEGIN_METHOD(CEDITORDOC_print, GB_STRING str; GB_INTEGER y; GB_INTEGER x)
 
-	QString s = QSTRING_ARG(str);
-	uint i, j, code;
+	char *str = STRING(str);
+	int len = LENGTH(str);
+	int i, j;
   int line, col;
+  unsigned char c;
 
 	if (!MISSING(y) && !MISSING(x))
 		WIDGET->cursorGoto(VARG(y), VARG(x), false);
 	
 	j = 0;
-	for (i = 0; i < s.length(); i++)
+	for (i = 0; i < len; i++)
 	{
 		//if (s[i].latin1() < 32)
 		//	qDebug("%d", s[i].latin1());
-		code = s[i].unicode();
-		if (code < 32)
+		
+		c = str[i];
+		if (c < 32)
 		{
 			if (i > j)
-				print_text(THIS, s.mid(j, i - j));
+				print_text(THIS, &str[j], i - j);
 				
 			j = i + 1;
 			
  			WIDGET->getCursor(&line, &col);		
 			
-			if (code == '\t')
+			if (c == '\t')
 			{
-				QString spc = "        ";
-				int l = spc.length() - col % spc.length();
-				print_text(THIS, spc.left(l));
+				int l = 8 - col % 8;
+				print_text(THIS, "        ", l);
 			}
-			else if (code == '\r')
+			else if (c == '\r')
 			{
 				WIDGET->cursorGoto(line, 0, false);
 			}
-			else if (code == '\n')
+			else if (c == '\n')
 			{
 				WIDGET->cursorGoto(line, DOC->lineLength(line), false);
 				WIDGET->insert("\n");
 			}
+			else if (c == 12) // CTRL+L
+			{
+				DOC->clear();
+			}
+			else if (c == 7)
+			{
+				WIDGET->flash();
+			}
 			else
 			{
 				QString tmp;
-				tmp.sprintf("^%c", code + 64);
-				print_text(THIS, tmp);
+				tmp.sprintf("^%c", c + 64);
+				print_text(THIS, tmp, 2, true);
 			}
 		}
 	}
 
 	if (i > j)
-		print_text(THIS, s.mid(j, i - j));
+		print_text(THIS, &str[j], i - j);
 		
 END_METHOD
 
@@ -637,11 +677,13 @@ BEGIN_METHOD_VOID(CEDITOR_redo)
 
 END_METHOD
 
-BEGIN_METHOD(CEDITOR_to_pos_x, GB_INTEGER x)
+BEGIN_METHOD(CEDITOR_to_pos_x, GB_INTEGER x; GB_INTEGER y)
 
+  int line, col;
   int px, py;
 
-  WIDGET->cursorToPos(0, VARG(x), &px, &py);
+  WIDGET->getCursor(&line, &col);
+  WIDGET->cursorToPos(VARGOPT(y, line), VARG(x), &px, &py);
   GB.ReturnInteger(px);
 
 END_METHOD
@@ -921,7 +963,7 @@ GB_DESC CEditorDesc[] =
 
   GB_PROPERTY_READ("CursorX", "i", CEDITOR_cursor_x),
   GB_PROPERTY_READ("CursorY", "i", CEDITOR_cursor_y),
-  GB_METHOD("ToPosX", "i", CEDITOR_to_pos_x, "(Column)i"),
+  GB_METHOD("ToPosX", "i", CEDITOR_to_pos_x, "(Column)i[(Row)i]"),
   GB_PROPERTY_READ("LineHeight", "i", CEDITOR_line_height),
   GB_PROPERTY_READ("CharWidth", "i", CEDITOR_char_width),
 
