@@ -34,6 +34,7 @@
 #include <qcstring.h>
 #include <qevent.h>
 #include <qcolor.h>
+#include <qeventloop.h>
 
 #include "CWidget.h"
 #include "CImage.h"
@@ -191,42 +192,53 @@ END_PROPERTY
 BEGIN_METHOD(CCLIPBOARD_copy, GB_VARIANT data; GB_STRING format)
 
   QCString format;
+	int i;
 
-  if (VARG(data).type == GB_T_STRING)
-  {
-    QTextDrag *drag = new QTextDrag();
+	for (i = 0; i < 10; i++)
+	{
+		if (VARG(data).type == GB_T_STRING)
+		{
+			QString text = TO_QSTRING(VARG(data).value._string);
+			QTextDrag *drag = new QTextDrag(text);
 
-    if (MISSING(format))
-      format = "plain";
-    else
-    {
-      format = GB.ToZeroString(ARG(format));
-      if (format.left(5) != "text/")
-        goto _BAD_FORMAT;
-      format = format.mid(5);
-      if (format.length() == 0)
-        goto _BAD_FORMAT;
-    }
+			if (MISSING(format))
+				format = "plain";
+			else
+			{
+				format = GB.ToZeroString(ARG(format));
+				if (format.left(5) != "text/")
+					goto _BAD_FORMAT;
+				format = format.mid(5);
+				if (format.length() == 0)
+					goto _BAD_FORMAT;
+			}
 
-    drag->setText(TO_QSTRING(VARG(data)._string.value));
-    drag->setSubtype(format);
+			drag->setSubtype(format);
+			//drag->setText(text);
 
-    QApplication::clipboard()->setData(drag);
-  }
-  else if (VARG(data).type >= GB_T_OBJECT && GB.Is(VARG(data)._object.value, CLASS_Image))
-  {
-    CIMAGE *img;
+			QApplication::clipboard()->setData(drag, QClipboard::Clipboard);
+		}
+		else if (VARG(data).type >= GB_T_OBJECT && GB.Is(VARG(data).value._object, CLASS_Image))
+		{
+			CIMAGE *img;
 
-    if (!MISSING(format))
-      goto _BAD_FORMAT;
+			if (!MISSING(format))
+				goto _BAD_FORMAT;
 
-    img = (CIMAGE *)VARG(data)._object.value;
+			img = (CIMAGE *)VARG(data).value._object;
 
-    QApplication::clipboard()->setImage(*(img->image));
-  }
-  else
-    goto _BAD_FORMAT;
+			QApplication::clipboard()->setImage(*(img->image), QClipboard::Clipboard);
+		}
+		else
+			goto _BAD_FORMAT;
 
+		qApp->eventLoop()->processEvents(QEventLoop::ExcludeUserInput, 20);
+		if (QApplication::clipboard()->ownsClipboard())
+			break;
+	}
+
+	//qDebug("ownsClipboard: %d", QApplication::clipboard()->ownsClipboard());
+	
   return;
 
 _BAD_FORMAT:
@@ -400,17 +412,17 @@ void CDRAG_drag(CWIDGET *source, GB_VARIANT_VALUE *data, GB_STRING *fmt)
         goto _BAD_FORMAT;
     }
 
-    ((QTextDrag *)drag)->setText(data->_string.value);
+    ((QTextDrag *)drag)->setText(data->value._string);
     ((QTextDrag *)drag)->setSubtype(format);
   }
-  else if (data->type >= GB_T_OBJECT && GB.Is(data->_object.value, CLASS_Image))
+  else if (data->type >= GB_T_OBJECT && GB.Is(data->value._object, CLASS_Image))
   {
     if (fmt)
       goto _BAD_FORMAT;
 
     drag = new QImageDrag(source->widget);
 
-    img = (CIMAGE *)data->_object.value;
+    img = (CIMAGE *)data->value._object;
 
     ((QImageDrag *)drag)->setImage(*(img->image));
   }
@@ -526,14 +538,14 @@ bool CDRAG_drag_move(QWidget *w, CWIDGET *control, QDropEvent *e)
 	return cancel;
 }
 
-void CDRAG_drag_drop(QWidget *w, CWIDGET *control, QDropEvent *e)
+bool CDRAG_drag_drop(QWidget *w, CWIDGET *control, QDropEvent *e)
 {
 	QPoint p;
 
 	//hide_frame();
 
 	if (!GB.CanRaise(control, EVENT_Drop))
-		return;
+		return false;
 
 	// Hack for QScrollView
 	if (CWIDGET_test_flag(control, WF_SCROLLVIEW) && QWIDGET(control)->inherits("MyListView"))
@@ -550,6 +562,7 @@ void CDRAG_drag_drop(QWidget *w, CWIDGET *control, QDropEvent *e)
 	GB.Raise(control, EVENT_Drop, 0);
 
 	CDRAG_clear(false);
+	return true;
 }
 
 
