@@ -58,6 +58,7 @@ typedef
     CWIDGET widget;
     int index;
     bool sorted;
+		bool click;
     }
   CCOMBOBOX;
 
@@ -71,6 +72,8 @@ public:
   MyComboBox(QWidget *parent);
   void fontChange(const QFont &);
   void calcMinimumHeight();
+	
+	virtual void hide();
 };
 
 
@@ -82,10 +85,6 @@ public:
 
   static CTextBox manager;
 
-  static void getAll(QComboBox *list, GB_ARRAY array);
-  static void setAll(QComboBox *list, GB_ARRAY array);
-  static int find(QComboBox *list, const QString& elt);
-
 public slots:
 
   void event_change(void);
