@@ -400,13 +400,18 @@ static double get_music_pos(void)
 {
   double time;
 
-  if (Mix_PlayingMusic() && !Mix_PausedMusic())
-  {
-    GB.GetTime(&time, FALSE);
-    return music_ref_pos + time - music_ref_time;
-  }
-  else
-    return music_ref_pos;
+  if (Mix_PlayingMusic())
+	{
+		if (!Mix_PausedMusic())
+		{
+			GB.GetTime(&time, FALSE);
+			return music_ref_pos + time - music_ref_time;
+		}
+		else
+			return music_ref_pos;
+	}
+	else
+		return 0;
 }
 
 
@@ -494,6 +499,7 @@ BEGIN_PROPERTY(CMUSIC_pos)
   {
     pos = VPROP(GB_FLOAT);
     Mix_RewindMusic();
+    SDL_Delay(10);
     if (Mix_SetMusicPosition(pos) == 0)
       music_ref_pos = pos;
     else
@@ -503,7 +509,6 @@ BEGIN_PROPERTY(CMUSIC_pos)
 
 END_PROPERTY
 
-
 BEGIN_PROPERTY(CMUSIC_volume)
 
   if (READ_PROPERTY)
