@@ -25,6 +25,7 @@
 
 #include "config.h"
 #include <stdint.h>
+#include <stddef.h>
 
 /* Gambas API Version */
 
@@ -55,6 +56,10 @@
 #define EXPORT
 #endif
 
+#ifndef PACKED
+#define PACKED __attribute__((packed))
+#endif
+
 #if defined(__cplusplus)
 #define __null ((intptr_t)0)
 #endif
@@ -81,7 +86,7 @@
 /* This type represents a Gambas datatype identifier */
 
 typedef
-  intptr_t GB_TYPE;
+  uintptr_t GB_TYPE;
 
 
 /* This opaque type represents a Gambas class identifier */
@@ -98,39 +103,11 @@ typedef
 typedef
   struct {
     GB_CLASS klass;
-    int ref;
+    intptr_t ref;
     }
   GB_BASE;
 
 
-/* Gambas VARIANT datatype definition */
-
-typedef
-  union {
-    GB_TYPE type;
-		intptr_t _reserved[3];
-    struct { GB_TYPE type; int value; } _boolean;
-    struct { GB_TYPE type; int value; } _byte;
-    struct { GB_TYPE type; int value; } _short;
-    struct { GB_TYPE type; int value; } _integer;
-    struct { GB_TYPE type; int64_t value; } _long;
-    struct { GB_TYPE type; double value; } _single;
-    struct { GB_TYPE type; double value; } _float;
-    struct { GB_TYPE type; int date; int time; } _date;
-    struct { GB_TYPE type; char *value; } _string;
-    struct { GB_TYPE type; void *value; } _object;
-    }
-  GB_VARIANT_VALUE;
-
-
-typedef
-  struct {
-    GB_TYPE type;
-    GB_VARIANT_VALUE value;
-    }
-  GB_VARIANT;
-
-
 /* Gambas STRING datatype definition */
 
 typedef
@@ -162,16 +139,17 @@ typedef
   GB_INTEGER;
 
 
-/* Gambas INTEGER datatype definition */
+/* Gambas LONG datatype definition */
 
 typedef
   struct {
     GB_TYPE type;
+		#if __WORDSIZE == 32
+		int _pad;
+		#endif
     int64_t value;
     #if __WORDSIZE == 64
     intptr_t _reserved[2];
-    #else
-    int _reserved;
     #endif
     }
   GB_LONG;
@@ -206,11 +184,12 @@ typedef
 typedef
   struct {
     GB_TYPE type;
+    #if __WORDSIZE == 32
+		int _pad;
+		#endif
     double value;
     #if __WORDSIZE == 64
     intptr_t _reserved[2];
-    #else
-    int _reserved;
     #endif
     }
   GB_FLOAT;
@@ -228,7 +207,7 @@ typedef
 typedef
   struct {
     GB_TYPE type;
-    GB_DATE_VALUE value;
+		GB_DATE_VALUE value;
     #if __WORDSIZE == 64
     intptr_t _reserved[2];
     #else
@@ -249,6 +228,41 @@ typedef
   GB_OBJECT;
 
 
+/* Gambas VARIANT datatype definition */
+
+typedef
+  struct {
+    GB_TYPE type;
+		union {
+			char _boolean;
+			unsigned char _byte;
+			short _short;
+			int _integer;
+			int64_t _long;
+			float _single;
+			double _float;
+			GB_DATE_VALUE _date;
+			char *_string;
+			void *_object;
+			int64_t data;
+			}
+			value;
+		}
+	PACKED
+  GB_VARIANT_VALUE;
+
+typedef
+  struct {
+    GB_TYPE type;
+		GB_VARIANT_VALUE value;
+		#if __WORDSIZE == 64
+		int64_t _pad;
+		#endif
+    }
+	PACKED
+  GB_VARIANT;
+
+
 /* Gambas common value definition */
 
 typedef
@@ -670,11 +684,23 @@ typedef
     }
   GB_STREAM_DESC;
 
+typedef
+  struct {
+    GB_STREAM_DESC *desc;
+    intptr_t _reserved;
+    }
+  GB_STREAM_BASE;
+
 typedef
   struct GB_STREAM {
     GB_STREAM_DESC *desc;
-    int _reserved;
-    int _free[6];
+    intptr_t _reserved;
+    void *tag;
+    #if __WORDSIZE == 64
+    int _free[4];
+    #else
+    int _free[5];
+    #endif
     }
   GB_STREAM;
 
@@ -846,7 +872,7 @@ typedef
     void (*MakeDateFromTime)(int, int, GB_DATE *);
     int (*GetTime)(double *, int);
 
-    void (*Watch)(int, int, void *, int);
+    void (*Watch)(int, int, void *, intptr_t);
 
     GB_VALUE *(*Eval)(void *, void *);
 
