@@ -276,6 +276,9 @@ void THROW(int code, ...)
 	int i;
 	char *arg[4];
 
+	//if (code == E_SYSTEM)
+	//	fprintf(stderr, "THROW system error from %s\n", DEBUG_get_current_position());
+
 	va_start(args, code);
 
 	for (i = 0; i < 4; i++)
@@ -360,9 +363,21 @@ void ERROR_print_at(FILE *where, bool msgonly, bool newline)
 			fprintf(where, "%ld:", ERROR_info.code);*/
 		if (ERROR_info.code > 0)
 			fprintf(where, "#%d: ", ERROR_info.code);
+		fprintf(where, "%s", ERROR_info.msg);
+	}
+	else
+	{
+		char *p = ERROR_info.msg;
+		char c;
+		
+		while ((c = *p++))
+		{
+			if (c == '\n') c = ' ';
+				fputc(c, where);
+		}
 	}
 
-	fprintf(where, "%s", ERROR_info.msg);
+	
 	if (newline)
 		fputc('\n', where);
 }
