@@ -42,7 +42,9 @@ typedef
     OBJECT object;
     HASH_TABLE *hash_table;
     HASH_NODE *last;
-    int mode;
+		short mode;
+		bool locked;
+		char _reserved;
     }
   CCOLLECTION;
 
