@@ -230,33 +230,33 @@ END_PROPERTY
 
 BEGIN_PROPERTY(CFILE_atime)
 
-  GB_DATE date;
+  VALUE date;
 
-  DATE_from_time(THIS_STAT->info.atime, 0, (VALUE *)&date);
+  DATE_from_time(THIS_STAT->info.atime, 0, &date);
 
-  GB_ReturnDate(&date);
+  GB_ReturnDate((GB_DATE *)&date);
 
 END_PROPERTY
 
 
 BEGIN_PROPERTY(CFILE_ctime)
 
-  GB_DATE date;
+  VALUE date;
 
-  DATE_from_time(THIS_STAT->info.ctime, 0, (VALUE *)&date);
+  DATE_from_time(THIS_STAT->info.ctime, 0, &date);
 
-  GB_ReturnDate(&date);
+  GB_ReturnDate((GB_DATE *)&date);
 
 END_PROPERTY
 
 
 BEGIN_PROPERTY(CFILE_mtime)
 
-  GB_DATE date;
+  VALUE date;
 
-  DATE_from_time(THIS_STAT->info.mtime, 0, (VALUE *)&date);
+  DATE_from_time(THIS_STAT->info.mtime, 0, &date);
 
-  GB_ReturnDate(&date);
+  GB_ReturnDate((GB_DATE *)&date);
 
 END_PROPERTY
 
@@ -408,18 +408,18 @@ BEGIN_METHOD(CFILE_perm_get, GB_STRING user)
   who = get_file_user(THIS);
   if (strcmp(user, who) == 0)
   {
-    return_perm(THIS_STAT, S_IRUSR, S_IWUSR, S_IWUSR);
+    return_perm(THIS_STAT, S_IRUSR, S_IWUSR, S_IXUSR);
     return;
   }
 
   who = get_file_group(THIS);
   if (strlen(user) > 2 && user[0] == '*' && user[1] == '.' && strcmp(&user[2], who) == 0)
   {
-    return_perm(THIS_STAT, S_IRGRP, S_IWGRP, S_IWGRP);
+    return_perm(THIS_STAT, S_IRGRP, S_IWGRP, S_IXGRP);
     return;
   }
 
-  return_perm(THIS_STAT, S_IROTH, S_IWOTH, S_IWOTH);
+  return_perm(THIS_STAT, S_IROTH, S_IWOTH, S_IXOTH);
 
 END_METHOD
 
@@ -468,32 +468,41 @@ static void split_path(char *path)
 
 static void return_path(void)
 {
-  char *tmp = NULL;
-  int len;
+	char *tmp = NULL;
+	int len = strlen(_dir);
+	
+	STRING_add(&tmp, _dir, len);
+	
+	if (_name && *_name)
+	{
+		_basename = _name;
+		_ext = "";
+		_name = NULL;
+	}
 
-  len = strlen(_dir);
+	if (*_basename || *_ext)
+	{
+		if (*_dir && _dir[len - 1] != '/')
+		{
+			if (*_basename)
+			{
+				if (*_basename != '/')
+					STRING_add(&tmp, "/", 1);
+				STRING_add(&tmp, _basename, 0);
+			}
+			else if (*_ext)
+				STRING_add(&tmp, "/", 1);
+		}
+		
+		if (*_ext && *_ext != '.')
+			STRING_add(&tmp, ".", 1);
+		
+		STRING_add(&tmp, _ext, 0);
+	}
 
-  STRING_add(&tmp, _dir, len);
-  if (_name && *_name)
-  {
-    _basename = _name;
-    _ext = "";
-    _name = NULL;
-  }
+	STRING_extend_end(&tmp);
 
-  if (*_basename || *_ext)
-  {
-    if (*_dir && _dir[len - 1] != '/' && *_basename && *_basename != '/')
-      STRING_add(&tmp, "/", 1);
-    STRING_add(&tmp, _basename, 0);
-    if (*_ext && *_ext != '.')
-      STRING_add(&tmp, ".", 1);
-    STRING_add(&tmp, _ext, 0);
-  }
-
-  STRING_extend_end(&tmp);
-
-  GB_ReturnString(tmp);
+	GB_ReturnString(tmp);
 }
 
 BEGIN_METHOD(CFILE_dir, GB_STRING path)
