@@ -643,18 +643,15 @@ bool CLASS_unref(void *ob, boolean can_free)
 		DEBUG_get_current_position(),
 		OBJECT_class(object)->name, GET_ALLOC_ID(object), object->ref - 1);
 	#else
-	if (object->ref <= 0)
-		fprintf(stderr, "*** %p REF = %d !\n", object, object->ref);
-
 	fprintf(stderr, "%s, %s: unref(%s %p) -> %d\n", OBJECT_ref_where,
 		DEBUG_get_current_position(),
 		OBJECT_class(object)->name, object, object->ref - 1);
+
+	if (object->ref <= 0)
+		fprintf(stderr, "*** %p REF = %d !\n", object, object->ref);
 	#endif
 	fflush(stdout);
 
-	/*if (strcmp(OBJECT_class(object)->name, "Class") == 0)
-		fprintf(stderr, "Class ?\n");*/
-
 	if ((--(object->ref) <= 0) && can_free)
 	{
 		#if DEBUG_MEMORY
@@ -944,8 +941,13 @@ void CLASS_make_description(CLASS *class, CLASS_DESC *desc, int n_desc, int *fir
 
 void CLASS_calc_info(CLASS *class, int n_event, int size_dynamic, boolean all, int size_static)
 {
-	//char *stat;
-
+	// If the class is native and static, then size_dynamic == 0. But if we want to inherit 
+	// the static class, and make the inherited class dynamic, then class->off_event must 
+	// start after the object header. So we fix size_dynamic accordingly.
+	
+	if (all && size_dynamic == 0)
+		size_dynamic = sizeof(OBJECT);
+	
   if (class->parent)
   {
     if (all)
