@@ -230,7 +230,7 @@ void EXTERN_call(void)
     &&__STRING, &&__STRING, &&__VARIANT, &&__ARRAY, &&__FUNCTION, &&__CLASS, &&__NULL, &&__OBJECT
     };
   static const int use_temp[17] = { 0, 0, 0, 0, 0, 0, sizeof(float), 0, 0, sizeof(char *), sizeof(char *), 0, 0, 0, 0, 0, sizeof(void *) };
-  static char temp[4 * sizeof(void *)];
+  static char temp[16 * sizeof(void *)];
   static void *null = 0;
     
   CLASS_EXTERN *ext = &EXEC.class->load->ext[EXEC.index];
@@ -347,28 +347,23 @@ void EXTERN_call(void)
     case T_BYTE:
     case T_SHORT:
     case T_INTEGER:
-      //GB_ReturnInteger(*(int *)POINTER(rvalue));
       GB_ReturnInteger(rvalue._integer);
       break;
     
     case T_LONG:
-      //GB_ReturnLong(*(int64_t *)POINTER(rvalue));
       GB_ReturnLong(rvalue._long);
       break;
     
     case T_SINGLE:
-      //GB_ReturnFloat(*(float *)POINTER(rvalue));
       GB_ReturnFloat(rvalue._single);
       break;
       
     case T_FLOAT:
-      //GB_ReturnFloat(*(double *)POINTER(rvalue));
       GB_ReturnFloat(rvalue._float);
       break;
       
     case T_STRING:
-      //GB_ReturnConstString(*(char **)POINTER(rvalue), 0);
-      GB_ReturnConstString(rvalue._string, 0);
+      GB_ReturnConstZeroString(rvalue._string);
       break;
     
     default:
