@@ -425,7 +425,7 @@ static void add_identifier(bool no_res)
   boolean can_be_reserved;
   boolean can_be_subr;
   boolean is_type;
-  boolean last_func, last_declare, last_type;
+  boolean last_func, last_declare, last_type, last_class;
 
 	type = RT_IDENTIFIER;
 
@@ -459,13 +459,13 @@ static void add_identifier(bool no_res)
     not_first = (flag & RSF_INF) != 0;
     last_func = (flag & RSF_ILF) != 0;
     last_declare = (flag & RSF_ILD) != 0;
-    last_type = (flag & RSF_ILT) != 0;
-    //last_event = flag & RSF_ILE;
+		last_class = (flag & RSF_ILC) != 0;
+    last_type = last_class || (flag & RSF_ILT) != 0;
   }
   else
   {
     flag = 0;
-    not_first = last_func = last_declare = last_type = FALSE;
+    not_first = last_func = last_declare = last_type = last_class = FALSE;
   }
 
   car = get_char();
@@ -475,7 +475,7 @@ static void add_identifier(bool no_res)
   else
     can_be_reserved = !not_first && TABLE_find_symbol(COMP_res_table, &EVAL->source[start], len, NULL, &index);*/
 
-  can_be_reserved = car != '}' && !not_first;
+  can_be_reserved = car != '}' && !not_first && !last_class;
   
   if (can_be_reserved)
   {
