@@ -34,11 +34,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/mman.h>
-
-#include <sys/param.h>
 #include <sys/stat.h>
-
-
 #include <dirent.h>
 
 #ifdef PROJECT_EXEC
@@ -82,6 +78,9 @@ typedef
 static void push_path(void **list, const char *path)
 {
   FILE_PATH *slot;
+	
+	if (!path)
+		return;
 
   ALLOC(&slot, sizeof(FILE_PATH), "push_path");
   STRING_new(&slot->path, path, 0);
@@ -226,7 +225,7 @@ PUBLIC const char *FILE_cat(const char *path, ...)
 
     if (len > 0)
     {
-      if ((p + len) > &file_buffer[MAX_PATH])
+      if ((p + len) > &file_buffer[PATH_MAX])
         return NULL;
 
       if (p != path)
@@ -347,7 +346,7 @@ PUBLIC const char *FILE_set_ext(const char *path, const char *ext)
     return path;
   }
 
-  if (&p[strlen(ext)] >= &file_buffer[MAX_PATH])
+  if (&p[strlen(ext)] >= &file_buffer[PATH_MAX])
     return path;
 
   if (p == path || p[-1] != '.')
@@ -847,7 +846,7 @@ PUBLIC const char *FILE_getcwd(const char *subdir)
 
 PUBLIC const char *FILE_readlink(const char *link)
 {
-  int len = readlink(link, file_buffer, MAX_PATH);
+  int len = readlink(link, file_buffer, PATH_MAX);
 
   if (len < 0)
     return NULL;
